@@ -5,6 +5,10 @@ pub fn ttl(connection: &mut Connection, key: &str) -> Result<i64, RedisError> {
     redis::cmd("ttl").arg(key).query(connection)
 }
 
+pub fn get_type(connection: &mut Connection, key: &str) -> Result<String, RedisError> {
+    redis::cmd("type").arg(key).query(connection)
+}
+
 pub fn get(connection: &mut Connection, key: &str) -> Result<String, RedisError> {
     redis::cmd("get").arg(key).query(connection)
 }
